==> kpipewire-5.27.5-1-armv7h.pkg.tar.xz: usr/include/KPipeWire/kpipewiredmabuf_export.h <==

#ifndef KPIPEWIREDMABUF_EXPORT_H
#define KPIPEWIREDMABUF_EXPORT_H

#ifdef KPIPEWIREDMABUF_STATIC_DEFINE
#  define KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_NO_EXPORT
#else
#  ifndef KPIPEWIREDMABUF_EXPORT
#    ifdef KPipeWireDmaBuf_EXPORTS
        /* We are building this library */
#      define KPIPEWIREDMABUF_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KPIPEWIREDMABUF_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KPIPEWIREDMABUF_NO_EXPORT
#    define KPIPEWIREDMABUF_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED
#  define KPIPEWIREDMABUF_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT
#  define KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT
#  define KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KPIPEWIREDMABUF_NO_DEPRECATED
#    define KPIPEWIREDMABUF_NO_DEPRECATED
#  endif
#endif

#define KPIPEWIREDMABUF_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

#if defined(KPIPEWIREDMABUF_NO_DEPRECATED)
#  undef KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT
#elif defined(KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS)
#  define KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT
#else
#  define KPIPEWIREDMABUF_DEPRECATED KPIPEWIREDMABUF_DECL_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KPIPEWIREDMABUF_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KPIPEWIREDMABUF_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KPIPEWIREDMABUF_NO_DEPRECATED
#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b05
#endif
#ifdef KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS
#  define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE
#  ifdef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x51b05
#  endif
#endif

#ifndef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
#endif

#ifdef KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KPIPEWIREDMABUF_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KPIPEWIREDMABUF_EXPORT_H */

==> kpipewire-5.27.8-2-armv7h.pkg.tar.xz: usr/include/KPipeWire/kpipewiredmabuf_export.h <==

#ifndef KPIPEWIREDMABUF_EXPORT_H
#define KPIPEWIREDMABUF_EXPORT_H

#ifdef KPIPEWIREDMABUF_STATIC_DEFINE
#  define KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_NO_EXPORT
#else
#  ifndef KPIPEWIREDMABUF_EXPORT
#    ifdef KPipeWireDmaBuf_EXPORTS
        /* We are building this library */
#      define KPIPEWIREDMABUF_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KPIPEWIREDMABUF_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KPIPEWIREDMABUF_NO_EXPORT
#    define KPIPEWIREDMABUF_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED
#  define KPIPEWIREDMABUF_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT
#  define KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED
#endif

#ifndef KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT
#  define KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KPIPEWIREDMABUF_NO_DEPRECATED
#    define KPIPEWIREDMABUF_NO_DEPRECATED
#  endif
#endif

#define KPIPEWIREDMABUF_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KPIPEWIREDMABUF_NO_DEPRECATED)
#  undef KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT
#elif defined(KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS)
#  define KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_NO_EXPORT
#else
#  define KPIPEWIREDMABUF_DEPRECATED KPIPEWIREDMABUF_DECL_DEPRECATED
#  define KPIPEWIREDMABUF_DEPRECATED_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED_EXPORT
#  define KPIPEWIREDMABUF_DEPRECATED_NO_EXPORT KPIPEWIREDMABUF_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KPIPEWIREDMABUF_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KPIPEWIREDMABUF_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KPIPEWIREDMABUF_NO_DEPRECATED
#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b08
#endif
#ifdef KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS
#  define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE
#  ifdef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x51b08
#  endif
#endif

#ifndef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
#endif

#ifdef KPIPEWIREDMABUF_DEPRECATED
#  define KPIPEWIREDMABUF_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KPIPEWIREDMABUF_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KPIPEWIREDMABUF_EXPORT_H */
